@@ -1,13 +1,13 @@
-/* exchng.f -- translated by f2c (version 19991025).
+/* exchng.f -- translated by f2c (version 20020621).
    You must link the resulting object file with the libraries:
 	-lf2c -lm   (in that order)
 */
 
 #include "f2c.h"
 
-/* Subroutine */ int exchng_(a, b, c__, d__, x, y, t, q, n)
-doublereal *a, *b, *c__, *d__, *x, *y, *t, *q;
-integer *n;
+/* Subroutine */ int exchng_(doublereal *a, doublereal *b, doublereal *c__, 
+	doublereal *d__, doublereal *x, doublereal *y, doublereal *t, 
+	doublereal *q, integer *n)
 {
     /* System generated locals */
     integer i__1;
