@@ -1,4 +1,4 @@
-/* fmat.f -- translated by f2c (version 19991025).
+/* fmat.f -- translated by f2c (version 20020621).
    You must link the resulting object file with the libraries:
 	-lf2c -lm   (in that order)
 */
@@ -89,10 +89,8 @@ static integer c__1 = 1;
 static logical c_true = TRUE_;
 static integer c__0 = 0;
 
-/* Subroutine */ int fmat_(fmatrx, nreal, tscf, tder, deldip, heat)
-doublereal *fmatrx;
-integer *nreal;
-doublereal *tscf, *tder, *deldip, *heat;
+/* Subroutine */ int fmat_(doublereal *fmatrx, integer *nreal, doublereal *
+	tscf, doublereal *tder, doublereal *deldip, doublereal *heat)
 {
     /* Initialized data */
 
@@ -103,56 +101,59 @@ doublereal *tscf, *tder, *deldip, *heat;
     doublereal d__1, d__2;
 
     /* Builtin functions */
-    integer i_indx(), s_wsfe(), e_wsfe(), do_fio();
-    double sqrt();
-    /* Subroutine */ int s_stop();
+    integer i_indx(char *, char *, ftnlen, ftnlen), s_wsfe(cilist *), e_wsfe(
+	    void), do_fio(integer *, char *, ftnlen);
+    double sqrt(doublereal);
+    /* Subroutine */ int s_stop(char *, ftnlen);
 
     /* Local variables */
-    static doublereal grad[360], escf, eigs[360];
-    static logical prnt;
-    extern /* Subroutine */ int symr_();
-    static doublereal g2rad[360], g2old[360], time2, time3;
     static integer i__, j, k, l;
     static doublereal q[120];
+    static integer ii, kk, ll, lu;
+    static logical big, log__;
+    static integer lin;
+    extern doublereal dot_(doublereal *, doublereal *, integer *);
+    static doublereal sum, del2[3], grad[360], escf, eigs[360];
+    static logical prnt;
+    extern /* Subroutine */ int symr_(void);
+    static doublereal g2rad[360], g2old[360], time2, time3;
     static logical debug;
-    extern /* Subroutine */ int chrge_();
+    extern /* Subroutine */ int chrge_(doublereal *, doublereal *);
     static doublereal delta, grold[360];
     static integer iskip;
     static doublereal estim;
     static integer iloop;
     static doublereal tlast;
     static logical group;
-    static doublereal tstep;
-    static integer ii;
-    static doublereal heataa;
-    static integer kk, ll, lu;
-    extern doublereal second_();
-    extern /* Subroutine */ int compfg_();
-    extern doublereal dipole_();
+    static doublereal tstep, heataa;
+    extern doublereal second_(void);
+    extern /* Subroutine */ int compfg_(doublereal *, logical *, doublereal *,
+	     logical *, doublereal *, logical *);
+    extern doublereal dipole_(doublereal *, doublereal *, doublereal *, 
+	    doublereal *, integer *);
 #define coordl ((doublereal *)&coord_1)
     static logical resfil, precis;
     static doublereal fconst[360], estime;
-    extern /* Subroutine */ int forsav_();
+    extern /* Subroutine */ int forsav_(doublereal *, doublereal *, integer *,
+	     doublereal *, doublereal *, integer *, doublereal *, doublereal *
+	    , integer *, doublereal *);
     static doublereal totime;
     static integer istart, jstart, kountf;
     static logical restrt;
-    extern /* Subroutine */ int sympop_();
-    static logical big, log__;
-    static integer lin;
-    extern doublereal dot_();
-    static doublereal sum, del2[3];
+    extern /* Subroutine */ int sympop_(doublereal *, integer *, integer *, 
+	    doublereal *);
 
     /* Fortran I/O blocks */
-    static cilist io___12 = { 0, 6, 0, "(//4X,'FIRST DERIVATIVES WILL BE USE\
-D IN THE'  ,' CALCULATION OF SECOND DERIVATIVES')", 0 };
-    static cilist io___22 = { 0, 6, 0, "(/10X,'ESTIMATED TIME TO COMPLETE CA\
-LCULATION ='       ,F9.2,' SECONDS')", 0 };
-    static cilist io___23 = { 0, 6, 0, "(/10X,'STARTING AGAIN AT LINE',18X,I\
-4)", 0 };
-    static cilist io___24 = { 0, 6, 0, "(/10X,'TIME USED UP TO RESTART =',F2\
-2.2)", 0 };
-    static cilist io___29 = { 0, 6, 0, "(' STEP:',I4,'       ',9X,  '       \
-INTEGRAL =',F10.2,' TIME LEFT:',F10.2)", 0 };
+    static cilist io___12 = { 0, 6, 0, "(//4X,'FIRST DERIVATIVES WILL BE USE"
+	    "D IN THE'  ,' CALCULATION OF SECOND DERIVATIVES')", 0 };
+    static cilist io___22 = { 0, 6, 0, "(/10X,'ESTIMATED TIME TO COMPLETE CA"
+	    "LCULATION ='       ,F9.2,' SECONDS')", 0 };
+    static cilist io___23 = { 0, 6, 0, "(/10X,'STARTING AGAIN AT LINE',18X,I"
+	    "4)", 0 };
+    static cilist io___24 = { 0, 6, 0, "(/10X,'TIME USED UP TO RESTART =',F2"
+	    "2.2)", 0 };
+    static cilist io___29 = { 0, 6, 0, "(' STEP:',I4,'       ',9X,  '       "
+	    "INTEGRAL =',F10.2,' TIME LEFT:',F10.2)", 0 };
     static cilist io___33 = { 0, 6, 0, "(A,I3,A,F12.5)", 0 };
     static cilist io___34 = { 0, 6, 0, "(A,F12.5)", 0 };
     static cilist io___37 = { 0, 6, 0, "(A,F12.5)", 0 };
@@ -162,23 +163,23 @@ INTEGRAL =',F10.2,' TIME LEFT:',F10.2)", 0 };
     static cilist io___51 = { 0, 6, 0, "(A)", 0 };
     static cilist io___52 = { 0, 6, 0, "(A)", 0 };
     static cilist io___53 = { 0, 6, 0, "(I7,6F12.6)", 0 };
-    static cilist io___56 = { 0, 6, 0, "(' STEP:',I4,' RESTART FILE WRITTEN,\
- INTEGRAL =',F10.2,' TIME LEFT:',F10.2)", 0 };
-    static cilist io___57 = { 0, 11, 0, "(' STEP:',I4,' RESTART FILE WRITTEN\
-, ','INTEGRAL =',F10.2,' TIME LEFT:',F10.2)", 0 };
-    static cilist io___58 = { 0, 6, 0, "(' STEP:',I4,' TIME =',F9.2,' SECS, \
-INTEGRAL =',F10.2,' TIME LEFT:',F10.2)", 0 };
-    static cilist io___59 = { 0, 11, 0, "(' STEP:',I4,' TIME =',F9.2,' SECS,\
- ','INTEGRAL =',F10.2,' TIME LEFT:',F10.2)", 0 };
-    static cilist io___61 = { 0, 6, 0, "(//10X,'- - - - - - - TIME UP - - - \
-- - - -',//)", 0 };
+    static cilist io___56 = { 0, 6, 0, "(' STEP:',I4,' RESTART FILE WRITTEN,"
+	    " INTEGRAL =',F10.2,' TIME LEFT:',F10.2)", 0 };
+    static cilist io___57 = { 0, 11, 0, "(' STEP:',I4,' RESTART FILE WRITTEN"
+	    ", ','INTEGRAL =',F10.2,' TIME LEFT:',F10.2)", 0 };
+    static cilist io___58 = { 0, 6, 0, "(' STEP:',I4,' TIME =',F9.2,' SECS, "
+	    "INTEGRAL =',F10.2,' TIME LEFT:',F10.2)", 0 };
+    static cilist io___59 = { 0, 11, 0, "(' STEP:',I4,' TIME =',F9.2,' SECS,"
+	    " ','INTEGRAL =',F10.2,' TIME LEFT:',F10.2)", 0 };
+    static cilist io___61 = { 0, 6, 0, "(//10X,'- - - - - - - TIME UP - - - "
+	    "- - - -',//)", 0 };
     static cilist io___62 = { 0, 6, 0, "(/10X,' POINT REACHED =',I4)", 0 };
-    static cilist io___63 = { 0, 6, 0, "(/10X,' RESTART USING KEY-WORD \"RES\
-TART\"')", 0 };
-    static cilist io___64 = { 0, 6, 0, "(10X,'ESTIMATED TIME FOR THE NEXT ST\
-EP =',F8.2,  ' SECONDS')", 0 };
-    static cilist io___65 = { 0, 6, 0, "(//10X,'FORCE MATRIX WRITTEN TO DISK\
-')", 0 };
+    static cilist io___63 = { 0, 6, 0, "(/10X,' RESTART USING KEY-WORD \"RES"
+	    "TART\"')", 0 };
+    static cilist io___64 = { 0, 6, 0, "(10X,'ESTIMATED TIME FOR THE NEXT ST"
+	    "EP =',F8.2,  ' SECONDS')", 0 };
+    static cilist io___65 = { 0, 6, 0, "(//10X,'FORCE MATRIX WRITTEN TO DISK"
+	    "')", 0 };
     static cilist io___67 = { 0, 6, 0, "(A)", 0 };
     static cilist io___68 = { 0, 6, 0, "(A)", 0 };
 
@@ -545,8 +546,8 @@ EP =',F8.2,  ' SECONDS')", 0 };
 	    do_fio(&c__1, " CONTRIBUTIONS TO F-MATRIX", (ftnlen)26);
 	    e_wsfe();
 	    s_wsfe(&io___52);
-	    do_fio(&c__1, " ELEMENT  +1.0*DELTA  +0.5*DELTA  -0.5*DELTA  -1.\
-0*DELTA   2'ND ORDER 4TH ORDER", (ftnlen)79);
+	    do_fio(&c__1, " ELEMENT  +1.0*DELTA  +0.5*DELTA  -0.5*DELTA  -1."
+		    "0*DELTA   2'ND ORDER 4TH ORDER", (ftnlen)79);
 	    e_wsfe();
 	    s_wsfe(&io___53);
 	    i__2 = geovar_1.nvar;
